@@ -6,6 +6,7 @@ import tempfile
 import backstage
 from backstage.venue import use_venue
 from backstage.venue import Venue
+from backstage.utils import uwsgi_portsniffer
 import time
 
 
@@ -85,7 +86,18 @@ class Act():
         return logfile
 
     def get_uwsgi_port(self):
-        from backstage.utils import uwsgi_portsniffer
+        """Get the uwsgi port using lsof.  Requires that lsof and fuser be suid root"""
+        fullport = uwsgi_portsniffer.port_from_lsof(self.vassal_file)
+        try:
+            self.uwsgi_ip, self.uwsgi_port = fullport.split(':')
+        except:
+            self.uwsgi_ip = None; self.uwsgi_port = None
+        return
+
+
+    def sniff_uwsgi_port(self):
+        """sniff the uwsgi port from the log file. inefficient but does not require
+        root access"""
         ip, port = uwsgi_portsniffer.portsniffer(self.uwsgi_log)
         if port is None:
             print "No port.  Try self.uwsgi_linker(linkmode='link')"
